@@ -25,7 +25,17 @@ import os
 import logging
 import time
 import sys
-from typing import Any, Callable, Dict, List, MutableMapping, NoReturn, Optional, Union, overload
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    MutableMapping,
+    NoReturn,
+    Optional,
+    Sequence,
+    Union,
+    overload,
+)
 
 from urllib.parse import urlparse, urlunparse
 import configparser
@@ -249,11 +259,16 @@ class OpenQA_Client:
         retries: Optional[int] = None,
         wait: Optional[int] = None,
         data: Any = None,
+        json: Any = None,
     ):
         """Perform a typical openQA request, with an API path and some
         optional parameters. Use the data parameter instead of params if you
         need to pass lots of settings. It will post
-        application/x-www-form-urlencoded data.
+        application/x-www-form-urlencoded data. Use the json parameter if you
+        are POSTing or PUTing to one of the endpoints that requires a
+        JSON-encoded request - test_suites, machines, or products. It will
+        send a request with JSON data and the required
+        Content-Type: application/json header.
 
         If either params or data is a dictionary and contains the key "settings"
         (which is a list of dictionaries), then the entries of "settings"
@@ -275,10 +290,10 @@ class OpenQA_Client:
         # groups, products, etc. that take a settings parameter, then this
         # settings parameter gets returned to us as a list like this:
         # [{"key": "varname", "value": "var_value"}]
-        # But when we sent the reply back, we must send these settings in the
-        # "top level" payload object like this:
-        # "settings[varname]": "var_value"
-        for payload in (params, data):
+        # But when we sent the reply back, we must send these settings in a
+        # simple dict like this:
+        # {"varname": "var_value"}
+        for payload in (params, data, json):
             if (
                 payload is not None
                 and isinstance(payload, dict)
@@ -286,8 +301,7 @@ class OpenQA_Client:
                 and isinstance(payload["settings"], list)
             ):
                 settings = payload.pop("settings")
-                for setting in settings:
-                    payload[f"settings[{setting.get('key')}]"] = setting["value"]
+                payload["settings"] = {setdict["key"]: setdict["value"] for setdict in settings}
 
         # As with the reference client, we assume relative paths are
         # relative to /api/v1.
@@ -295,10 +309,10 @@ class OpenQA_Client:
             path = f"/api/v1/{path}"
 
         url = f"{self.baseurl}{path}"
-        req = requests.Request(method=method.upper(), url=url, params=params, data=data)
+        req = requests.Request(method=method.upper(), url=url, params=params, data=data, json=json)
         return self.do_request(req, retries=retries, wait=wait, parse=True)
 
-    def find_clones(self, jobs: List[Job]) -> List[Job]:
+    def find_clones(self, jobs: Sequence[Job]) -> Sequence[Job]:
         """Given an iterable of job dicts, this will see if any of the
         jobs were cloned, and replace any that were cloned with the dicts
         of their clones, returning a list. It recurses - so if 3 was
@@ -331,15 +345,18 @@ class OpenQA_Client:
 
     @overload
     def get_jobs(
-        self, jobs: Optional[List[Union[str, int]]], build: Optional[str], filter_dupes: bool
+        self,
+        jobs: Optional[Sequence[Union[str, int]]],
+        build: Optional[str],
+        filter_dupes: bool,
     ): ...  # pragma: no cover
 
     def get_jobs(
         self,
-        jobs: Optional[List[Union[str, int]]] = None,
+        jobs: Optional[Sequence[Union[str, int]]] = None,
         build: Optional[str] = None,
         filter_dupes: bool = True,
-    ):
+    ) -> Sequence[Union[Job, dict]]:
         """Get job dicts. Either 'jobs' or 'build' must be specified.
         'jobs' should be iterable of job IDs (string or int). 'build'
         should be an openQA BUILD to get all the jobs for. If both are
