@@ -259,6 +259,21 @@ class TestClient:
         assert fakedo.call_args[0][1].params == {}
         assert fakedo.call_args[1]["retries"] == 2
         assert fakedo.call_args[1]["wait"] == 5
+        # check requests with data work
+        fakedo.reset_mock()
+        client.openqa_request("get", "jobs", data=params)
+        prepped = fakedo.call_args[0][1].prepare()
+        assert prepped.body == "id=1"
+        assert prepped.headers == {
+            "Content-Length": "4",
+            "Content-Type": "application/x-www-form-urlencoded",
+        }
+        # check requests with json work
+        fakedo.reset_mock()
+        client.openqa_request("get", "jobs", json=params)
+        prepped = fakedo.call_args[0][1].prepare()
+        assert prepped.body == b'{"id": "1"}'
+        assert prepped.headers == {"Content-Length": "11", "Content-Type": "application/json"}
 
     @mock.patch("time.sleep", autospec=True)
     @mock.patch(
@@ -313,8 +328,10 @@ class TestClient:
         assert fakedo.call_args[0][1].params == {
             "id": "1",
             "name": "some_suite",
-            "settings[PUBLISH_HDD_1]": "%DISTRI%-%VERSION%-%ARCH%-%BUILD%.qcow2",
-            "settings[START_AFTER_TEST]": "fedora_rawhide_qcow2",
+            "settings": {
+                "PUBLISH_HDD_1": "%DISTRI%-%VERSION%-%ARCH%-%BUILD%.qcow2",
+                "START_AFTER_TEST": "fedora_rawhide_qcow2",
+            },
         }
         # check requests with a string payload
         fakedo.reset_mock()
